# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/proto/pnc_point.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/proto/pnc_point.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/common/proto/pnc_point.proto\x12\rapollo.common\"\x1f\n\x07SLPoint\x12\t\n\x01s\x18\x01 \x01(\x01\x12\t\n\x01l\x18\x02 \x01(\x01\"A\n\x10\x46renetFramePoint\x12\t\n\x01s\x18\x01 \x01(\x01\x12\t\n\x01l\x18\x02 \x01(\x01\x12\n\n\x02\x64l\x18\x03 \x01(\x01\x12\x0b\n\x03\x64\x64l\x18\x04 \x01(\x01\"D\n\nSpeedPoint\x12\t\n\x01s\x18\x01 \x01(\x01\x12\t\n\x01t\x18\x02 \x01(\x01\x12\t\n\x01v\x18\x03 \x01(\x01\x12\t\n\x01\x61\x18\x04 \x01(\x01\x12\n\n\x02\x64\x61\x18\x05 \x01(\x01\"\xb3\x01\n\tPathPoint\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\x12\r\n\x05theta\x18\x04 \x01(\x01\x12\r\n\x05kappa\x18\x05 \x01(\x01\x12\t\n\x01s\x18\x06 \x01(\x01\x12\x0e\n\x06\x64kappa\x18\x07 \x01(\x01\x12\x0f\n\x07\x64\x64kappa\x18\x08 \x01(\x01\x12\x0f\n\x07lane_id\x18\t \x01(\t\x12\x14\n\x0cx_derivative\x18\n \x01(\x01\x12\x14\n\x0cy_derivative\x18\x0b \x01(\x01\"B\n\x04Path\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\npath_point\x18\x02 \x03(\x0b\x32\x18.apollo.common.PathPoint\"\xbb\x01\n\x0fTrajectoryPoint\x12,\n\npath_point\x18\x01 \x01(\x0b\x32\x18.apollo.common.PathPoint\x12\t\n\x01v\x18\x02 \x01(\x01\x12\t\n\x01\x61\x18\x03 \x01(\x01\x12\x15\n\rrelative_time\x18\x04 \x01(\x01\x12\n\n\x02\x64\x61\x18\x05 \x01(\x01\x12\r\n\x05steer\x18\x06 \x01(\x01\x12\x32\n\rgaussian_info\x18\x07 \x01(\x0b\x32\x1b.apollo.common.GaussianInfo\"T\n\nTrajectory\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x10trajectory_point\x18\x02 \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"]\n\x12VehicleMotionPoint\x12\x38\n\x10trajectory_point\x18\x01 \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12\r\n\x05steer\x18\x02 \x01(\x01\"^\n\rVehicleMotion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12?\n\x14vehicle_motion_point\x18\x02 \x03(\x0b\x32!.apollo.common.VehicleMotionPoint\"\x96\x01\n\x0cGaussianInfo\x12\x0f\n\x07sigma_x\x18\x01 \x01(\x01\x12\x0f\n\x07sigma_y\x18\x02 \x01(\x01\x12\x13\n\x0b\x63orrelation\x18\x03 \x01(\x01\x12\x18\n\x10\x61rea_probability\x18\x04 \x01(\x01\x12\x11\n\tellipse_a\x18\x05 \x01(\x01\x12\x11\n\tellipse_b\x18\x06 \x01(\x01\x12\x0f\n\x07theta_a\x18\x07 \x01(\x01'
)




_SLPOINT = _descriptor.Descriptor(
  name='SLPoint',
  full_name='apollo.common.SLPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.common.SLPoint.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l', full_name='apollo.common.SLPoint.l', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=86,
)


_FRENETFRAMEPOINT = _descriptor.Descriptor(
  name='FrenetFramePoint',
  full_name='apollo.common.FrenetFramePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.common.FrenetFramePoint.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='l', full_name='apollo.common.FrenetFramePoint.l', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dl', full_name='apollo.common.FrenetFramePoint.dl', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ddl', full_name='apollo.common.FrenetFramePoint.ddl', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=153,
)


_SPEEDPOINT = _descriptor.Descriptor(
  name='SpeedPoint',
  full_name='apollo.common.SpeedPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.common.SpeedPoint.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='apollo.common.SpeedPoint.t', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='apollo.common.SpeedPoint.v', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.common.SpeedPoint.a', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='da', full_name='apollo.common.SpeedPoint.da', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=223,
)


_PATHPOINT = _descriptor.Descriptor(
  name='PathPoint',
  full_name='apollo.common.PathPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.common.PathPoint.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.common.PathPoint.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.common.PathPoint.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.common.PathPoint.theta', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa', full_name='apollo.common.PathPoint.kappa', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.common.PathPoint.s', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dkappa', full_name='apollo.common.PathPoint.dkappa', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ddkappa', full_name='apollo.common.PathPoint.ddkappa', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.common.PathPoint.lane_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x_derivative', full_name='apollo.common.PathPoint.x_derivative', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y_derivative', full_name='apollo.common.PathPoint.y_derivative', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=405,
)


_PATH = _descriptor.Descriptor(
  name='Path',
  full_name='apollo.common.Path',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.common.Path.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_point', full_name='apollo.common.Path.path_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=473,
)


_TRAJECTORYPOINT = _descriptor.Descriptor(
  name='TrajectoryPoint',
  full_name='apollo.common.TrajectoryPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path_point', full_name='apollo.common.TrajectoryPoint.path_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='apollo.common.TrajectoryPoint.v', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='apollo.common.TrajectoryPoint.a', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_time', full_name='apollo.common.TrajectoryPoint.relative_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='da', full_name='apollo.common.TrajectoryPoint.da', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer', full_name='apollo.common.TrajectoryPoint.steer', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gaussian_info', full_name='apollo.common.TrajectoryPoint.gaussian_info', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=663,
)


_TRAJECTORY = _descriptor.Descriptor(
  name='Trajectory',
  full_name='apollo.common.Trajectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.common.Trajectory.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.common.Trajectory.trajectory_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=749,
)


_VEHICLEMOTIONPOINT = _descriptor.Descriptor(
  name='VehicleMotionPoint',
  full_name='apollo.common.VehicleMotionPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.common.VehicleMotionPoint.trajectory_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steer', full_name='apollo.common.VehicleMotionPoint.steer', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=844,
)


_VEHICLEMOTION = _descriptor.Descriptor(
  name='VehicleMotion',
  full_name='apollo.common.VehicleMotion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.common.VehicleMotion.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_motion_point', full_name='apollo.common.VehicleMotion.vehicle_motion_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=940,
)


_GAUSSIANINFO = _descriptor.Descriptor(
  name='GaussianInfo',
  full_name='apollo.common.GaussianInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sigma_x', full_name='apollo.common.GaussianInfo.sigma_x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sigma_y', full_name='apollo.common.GaussianInfo.sigma_y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correlation', full_name='apollo.common.GaussianInfo.correlation', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_probability', full_name='apollo.common.GaussianInfo.area_probability', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ellipse_a', full_name='apollo.common.GaussianInfo.ellipse_a', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ellipse_b', full_name='apollo.common.GaussianInfo.ellipse_b', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta_a', full_name='apollo.common.GaussianInfo.theta_a', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1093,
)

_PATH.fields_by_name['path_point'].message_type = _PATHPOINT
_TRAJECTORYPOINT.fields_by_name['path_point'].message_type = _PATHPOINT
_TRAJECTORYPOINT.fields_by_name['gaussian_info'].message_type = _GAUSSIANINFO
_TRAJECTORY.fields_by_name['trajectory_point'].message_type = _TRAJECTORYPOINT
_VEHICLEMOTIONPOINT.fields_by_name['trajectory_point'].message_type = _TRAJECTORYPOINT
_VEHICLEMOTION.fields_by_name['vehicle_motion_point'].message_type = _VEHICLEMOTIONPOINT
DESCRIPTOR.message_types_by_name['SLPoint'] = _SLPOINT
DESCRIPTOR.message_types_by_name['FrenetFramePoint'] = _FRENETFRAMEPOINT
DESCRIPTOR.message_types_by_name['SpeedPoint'] = _SPEEDPOINT
DESCRIPTOR.message_types_by_name['PathPoint'] = _PATHPOINT
DESCRIPTOR.message_types_by_name['Path'] = _PATH
DESCRIPTOR.message_types_by_name['TrajectoryPoint'] = _TRAJECTORYPOINT
DESCRIPTOR.message_types_by_name['Trajectory'] = _TRAJECTORY
DESCRIPTOR.message_types_by_name['VehicleMotionPoint'] = _VEHICLEMOTIONPOINT
DESCRIPTOR.message_types_by_name['VehicleMotion'] = _VEHICLEMOTION
DESCRIPTOR.message_types_by_name['GaussianInfo'] = _GAUSSIANINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SLPoint = _reflection.GeneratedProtocolMessageType('SLPoint', (_message.Message,), {
  'DESCRIPTOR' : _SLPOINT,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.SLPoint)
  })
_sym_db.RegisterMessage(SLPoint)

FrenetFramePoint = _reflection.GeneratedProtocolMessageType('FrenetFramePoint', (_message.Message,), {
  'DESCRIPTOR' : _FRENETFRAMEPOINT,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.FrenetFramePoint)
  })
_sym_db.RegisterMessage(FrenetFramePoint)

SpeedPoint = _reflection.GeneratedProtocolMessageType('SpeedPoint', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDPOINT,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.SpeedPoint)
  })
_sym_db.RegisterMessage(SpeedPoint)

PathPoint = _reflection.GeneratedProtocolMessageType('PathPoint', (_message.Message,), {
  'DESCRIPTOR' : _PATHPOINT,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.PathPoint)
  })
_sym_db.RegisterMessage(PathPoint)

Path = _reflection.GeneratedProtocolMessageType('Path', (_message.Message,), {
  'DESCRIPTOR' : _PATH,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Path)
  })
_sym_db.RegisterMessage(Path)

TrajectoryPoint = _reflection.GeneratedProtocolMessageType('TrajectoryPoint', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYPOINT,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.TrajectoryPoint)
  })
_sym_db.RegisterMessage(TrajectoryPoint)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)

VehicleMotionPoint = _reflection.GeneratedProtocolMessageType('VehicleMotionPoint', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEMOTIONPOINT,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.VehicleMotionPoint)
  })
_sym_db.RegisterMessage(VehicleMotionPoint)

VehicleMotion = _reflection.GeneratedProtocolMessageType('VehicleMotion', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEMOTION,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.VehicleMotion)
  })
_sym_db.RegisterMessage(VehicleMotion)

GaussianInfo = _reflection.GeneratedProtocolMessageType('GaussianInfo', (_message.Message,), {
  'DESCRIPTOR' : _GAUSSIANINFO,
  '__module__' : 'modules.common.proto.pnc_point_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.GaussianInfo)
  })
_sym_db.RegisterMessage(GaussianInfo)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/perception/camera/common/proto/object_template_meta_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/perception/camera/common/proto/object_template_meta_schema.proto',
  package='apollo.perception.camera',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHmodules/perception/camera/common/proto/object_template_meta_schema.proto\x12\x18\x61pollo.perception.camera\"&\n\x03\x44im\x12\t\n\x01H\x18\x01 \x01(\x02\x12\t\n\x01W\x18\x02 \x01(\x02\x12\t\n\x01L\x18\x03 \x01(\x02\"Q\n\x0eObjectTemplate\x12\x13\n\x0bspeed_limit\x18\x01 \x01(\x02\x12*\n\x03\x64im\x18\x02 \x03(\x0b\x32\x1d.apollo.perception.camera.Dim\"\x8e\x06\n\x12ObjectTemplateMeta\x12\x39\n\x07unknown\x18\x01 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x41\n\x0funknown_movable\x18\x02 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x43\n\x11unknown_unmovable\x18\x03 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x35\n\x03\x63\x61r\x18\x04 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x35\n\x03van\x18\x05 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x37\n\x05truck\x18\x06 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x35\n\x03\x62us\x18\x07 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12\x39\n\x07\x63yclist\x18\x08 \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12>\n\x0cmotorcyclist\x18\t \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12<\n\ntricyclist\x18\n \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12<\n\npedestrian\x18\x0b \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12=\n\x0btrafficcone\x18\x0c \x01(\x0b\x32(.apollo.perception.camera.ObjectTemplate\x12!\n\x14max_dim_change_ratio\x18\x15 \x01(\x02:\x03\x30.1'
)




_DIM = _descriptor.Descriptor(
  name='Dim',
  full_name='apollo.perception.camera.Dim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='H', full_name='apollo.perception.camera.Dim.H', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='W', full_name='apollo.perception.camera.Dim.W', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='L', full_name='apollo.perception.camera.Dim.L', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=140,
)


_OBJECTTEMPLATE = _descriptor.Descriptor(
  name='ObjectTemplate',
  full_name='apollo.perception.camera.ObjectTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.perception.camera.ObjectTemplate.speed_limit', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim', full_name='apollo.perception.camera.ObjectTemplate.dim', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=223,
)


_OBJECTTEMPLATEMETA = _descriptor.Descriptor(
  name='ObjectTemplateMeta',
  full_name='apollo.perception.camera.ObjectTemplateMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unknown', full_name='apollo.perception.camera.ObjectTemplateMeta.unknown', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown_movable', full_name='apollo.perception.camera.ObjectTemplateMeta.unknown_movable', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unknown_unmovable', full_name='apollo.perception.camera.ObjectTemplateMeta.unknown_unmovable', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='car', full_name='apollo.perception.camera.ObjectTemplateMeta.car', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='van', full_name='apollo.perception.camera.ObjectTemplateMeta.van', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='truck', full_name='apollo.perception.camera.ObjectTemplateMeta.truck', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bus', full_name='apollo.perception.camera.ObjectTemplateMeta.bus', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cyclist', full_name='apollo.perception.camera.ObjectTemplateMeta.cyclist', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motorcyclist', full_name='apollo.perception.camera.ObjectTemplateMeta.motorcyclist', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tricyclist', full_name='apollo.perception.camera.ObjectTemplateMeta.tricyclist', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pedestrian', full_name='apollo.perception.camera.ObjectTemplateMeta.pedestrian', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trafficcone', full_name='apollo.perception.camera.ObjectTemplateMeta.trafficcone', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_dim_change_ratio', full_name='apollo.perception.camera.ObjectTemplateMeta.max_dim_change_ratio', index=12,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=1008,
)

_OBJECTTEMPLATE.fields_by_name['dim'].message_type = _DIM
_OBJECTTEMPLATEMETA.fields_by_name['unknown'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['unknown_movable'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['unknown_unmovable'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['car'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['van'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['truck'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['bus'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['cyclist'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['motorcyclist'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['tricyclist'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['pedestrian'].message_type = _OBJECTTEMPLATE
_OBJECTTEMPLATEMETA.fields_by_name['trafficcone'].message_type = _OBJECTTEMPLATE
DESCRIPTOR.message_types_by_name['Dim'] = _DIM
DESCRIPTOR.message_types_by_name['ObjectTemplate'] = _OBJECTTEMPLATE
DESCRIPTOR.message_types_by_name['ObjectTemplateMeta'] = _OBJECTTEMPLATEMETA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dim = _reflection.GeneratedProtocolMessageType('Dim', (_message.Message,), {
  'DESCRIPTOR' : _DIM,
  '__module__' : 'modules.perception.camera.common.proto.object_template_meta_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.Dim)
  })
_sym_db.RegisterMessage(Dim)

ObjectTemplate = _reflection.GeneratedProtocolMessageType('ObjectTemplate', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTEMPLATE,
  '__module__' : 'modules.perception.camera.common.proto.object_template_meta_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.ObjectTemplate)
  })
_sym_db.RegisterMessage(ObjectTemplate)

ObjectTemplateMeta = _reflection.GeneratedProtocolMessageType('ObjectTemplateMeta', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTEMPLATEMETA,
  '__module__' : 'modules.perception.camera.common.proto.object_template_meta_schema_pb2'
  # @@protoc_insertion_point(class_scope:apollo.perception.camera.ObjectTemplateMeta)
  })
_sym_db.RegisterMessage(ObjectTemplateMeta)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/tools/prediction/data_pipelines/proto/fnn_model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/tools/prediction/data_pipelines/proto/fnn_model.proto',
  package='',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=modules/tools/prediction/data_pipelines/proto/fnn_model.proto\"\x19\n\x06Vector\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\x01\"\x1f\n\x06Matrix\x12\x15\n\x04rows\x18\x01 \x03(\x0b\x32\x07.Vector\"\xf2\x01\n\x05Layer\x12\x17\n\x0flayer_input_dim\x18\x01 \x01(\x05\x12\x18\n\x10layer_output_dim\x18\x02 \x01(\x05\x12#\n\x12layer_input_weight\x18\x03 \x01(\x0b\x32\x07.Matrix\x12\x1b\n\nlayer_bias\x18\x04 \x01(\x0b\x32\x07.Vector\x12\x34\n\x15layer_activation_func\x18\x05 \x01(\x0e\x32\x15.Layer.ActivationFunc\">\n\x0e\x41\x63tivationFunc\x12\x08\n\x04RELU\x10\x00\x12\x08\n\x04TANH\x10\x01\x12\x0b\n\x07SIGMOID\x10\x02\x12\x0b\n\x07SOFTMAX\x10\x03\"\x98\x01\n\x08\x46nnModel\x12\x11\n\tdim_input\x18\x01 \x01(\x05\x12\x1d\n\x0csamples_mean\x18\x02 \x01(\x0b\x32\x07.Vector\x12\x1c\n\x0bsamples_std\x18\x03 \x01(\x0b\x32\x07.Vector\x12\x11\n\tnum_layer\x18\x04 \x01(\x05\x12\x15\n\x05layer\x18\x05 \x03(\x0b\x32\x06.Layer\x12\x12\n\ndim_output\x18\x06 \x01(\x05'
)



_LAYER_ACTIVATIONFUNC = _descriptor.EnumDescriptor(
  name='ActivationFunc',
  full_name='Layer.ActivationFunc',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RELU', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TANH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIGMOID', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOFTMAX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=306,
  serialized_end=368,
)
_sym_db.RegisterEnumDescriptor(_LAYER_ACTIVATIONFUNC)


_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='Vector.columns', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=90,
)


_MATRIX = _descriptor.Descriptor(
  name='Matrix',
  full_name='Matrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rows', full_name='Matrix.rows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=123,
)


_LAYER = _descriptor.Descriptor(
  name='Layer',
  full_name='Layer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='layer_input_dim', full_name='Layer.layer_input_dim', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_output_dim', full_name='Layer.layer_output_dim', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_input_weight', full_name='Layer.layer_input_weight', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_bias', full_name='Layer.layer_bias', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_activation_func', full_name='Layer.layer_activation_func', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LAYER_ACTIVATIONFUNC,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=368,
)


_FNNMODEL = _descriptor.Descriptor(
  name='FnnModel',
  full_name='FnnModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dim_input', full_name='FnnModel.dim_input', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samples_mean', full_name='FnnModel.samples_mean', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='samples_std', full_name='FnnModel.samples_std', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_layer', full_name='FnnModel.num_layer', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer', full_name='FnnModel.layer', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim_output', full_name='FnnModel.dim_output', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=523,
)

_MATRIX.fields_by_name['rows'].message_type = _VECTOR
_LAYER.fields_by_name['layer_input_weight'].message_type = _MATRIX
_LAYER.fields_by_name['layer_bias'].message_type = _VECTOR
_LAYER.fields_by_name['layer_activation_func'].enum_type = _LAYER_ACTIVATIONFUNC
_LAYER_ACTIVATIONFUNC.containing_type = _LAYER
_FNNMODEL.fields_by_name['samples_mean'].message_type = _VECTOR
_FNNMODEL.fields_by_name['samples_std'].message_type = _VECTOR
_FNNMODEL.fields_by_name['layer'].message_type = _LAYER
DESCRIPTOR.message_types_by_name['Vector'] = _VECTOR
DESCRIPTOR.message_types_by_name['Matrix'] = _MATRIX
DESCRIPTOR.message_types_by_name['Layer'] = _LAYER
DESCRIPTOR.message_types_by_name['FnnModel'] = _FNNMODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Vector = _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
  'DESCRIPTOR' : _VECTOR,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.fnn_model_pb2'
  # @@protoc_insertion_point(class_scope:Vector)
  })
_sym_db.RegisterMessage(Vector)

Matrix = _reflection.GeneratedProtocolMessageType('Matrix', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.fnn_model_pb2'
  # @@protoc_insertion_point(class_scope:Matrix)
  })
_sym_db.RegisterMessage(Matrix)

Layer = _reflection.GeneratedProtocolMessageType('Layer', (_message.Message,), {
  'DESCRIPTOR' : _LAYER,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.fnn_model_pb2'
  # @@protoc_insertion_point(class_scope:Layer)
  })
_sym_db.RegisterMessage(Layer)

FnnModel = _reflection.GeneratedProtocolMessageType('FnnModel', (_message.Message,), {
  'DESCRIPTOR' : _FNNMODEL,
  '__module__' : 'modules.tools.prediction.data_pipelines.proto.fnn_model_pb2'
  # @@protoc_insertion_point(class_scope:FnnModel)
  })
_sym_db.RegisterMessage(FnnModel)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/hmi_mode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/hmi_mode.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/dreamview/proto/hmi_mode.proto\x12\x10\x61pollo.dreamview\"0\n\x14ProcessMonitorConfig\x12\x18\n\x10\x63ommand_keywords\x18\x01 \x03(\t\"(\n\x13ModuleMonitorConfig\x12\x11\n\tnode_name\x18\x01 \x03(\t\"\x9d\x01\n\x14\x43hannelMonitorConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0b\x64\x65lay_fatal\x18\x02 \x01(\x01:\x01\x33\x12\x18\n\x10mandatory_fields\x18\x03 \x03(\t\x12 \n\x15min_frequency_allowed\x18\x04 \x01(\x01:\x01\x30\x12#\n\x15max_frequency_allowed\x18\x05 \x01(\x01:\x04\x31\x30\x30\x30\"\xce\x05\n\x15ResourceMonitorConfig\x12\x46\n\x0b\x64isk_spaces\x18\x01 \x03(\x0b\x32\x31.apollo.dreamview.ResourceMonitorConfig.DiskSpace\x12\x44\n\ncpu_usages\x18\x02 \x03(\x0b\x32\x30.apollo.dreamview.ResourceMonitorConfig.CPUUsage\x12J\n\rmemory_usages\x18\x03 \x03(\x0b\x32\x33.apollo.dreamview.ResourceMonitorConfig.MemoryUsage\x12J\n\x10\x64isk_load_usages\x18\x04 \x03(\x0b\x32\x30.apollo.dreamview.ResourceMonitorConfig.DiskLoad\x1a_\n\tDiskSpace\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\"\n\x1ainsufficient_space_warning\x18\x02 \x01(\x05\x12 \n\x18insufficient_space_error\x18\x03 \x01(\x05\x1a\x62\n\x08\x43PUUsage\x12\x1e\n\x16high_cpu_usage_warning\x18\x01 \x01(\x02\x12\x1c\n\x14high_cpu_usage_error\x18\x02 \x01(\x02\x12\x18\n\x10process_dag_path\x18\x03 \x01(\t\x1ak\n\x0bMemoryUsage\x12!\n\x19high_memory_usage_warning\x18\x01 \x01(\x05\x12\x1f\n\x17high_memory_usage_error\x18\x02 \x01(\x05\x12\x18\n\x10process_dag_path\x18\x03 \x01(\t\x1a]\n\x08\x44iskLoad\x12\x1e\n\x16high_disk_load_warning\x18\x01 \x01(\x05\x12\x1c\n\x14high_disk_load_error\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\"\x9b\x02\n\x12MonitoredComponent\x12\x37\n\x07process\x18\x01 \x01(\x0b\x32&.apollo.dreamview.ProcessMonitorConfig\x12\x37\n\x07\x63hannel\x18\x02 \x01(\x0b\x32&.apollo.dreamview.ChannelMonitorConfig\x12\x39\n\x08resource\x18\x03 \x01(\x0b\x32\'.apollo.dreamview.ResourceMonitorConfig\x12!\n\x13required_for_safety\x18\x04 \x01(\x08:\x04true\x12\x35\n\x06module\x18\x05 \x01(\x0b\x32%.apollo.dreamview.ModuleMonitorConfig\"\xa0\x01\n\x06Module\x12\x15\n\rstart_command\x18\x01 \x01(\t\x12\x14\n\x0cstop_command\x18\x02 \x01(\t\x12\x46\n\x16process_monitor_config\x18\x03 \x01(\x0b\x32&.apollo.dreamview.ProcessMonitorConfig\x12!\n\x13required_for_safety\x18\x04 \x01(\x08:\x04true\"Z\n\x0b\x43yberModule\x12\x11\n\tdag_files\x18\x01 \x03(\t\x12!\n\x13required_for_safety\x18\x02 \x01(\x08:\x04true\x12\x15\n\rprocess_group\x18\x03 \x01(\t\"\x82\x05\n\x07HMIMode\x12\x42\n\rcyber_modules\x18\x01 \x03(\x0b\x32+.apollo.dreamview.HMIMode.CyberModulesEntry\x12\x37\n\x07modules\x18\x02 \x03(\x0b\x32&.apollo.dreamview.HMIMode.ModulesEntry\x12P\n\x14monitored_components\x18\x03 \x03(\x0b\x32\x32.apollo.dreamview.HMIMode.MonitoredComponentsEntry\x12H\n\x10other_components\x18\x04 \x03(\x0b\x32..apollo.dreamview.HMIMode.OtherComponentsEntry\x1aR\n\x11\x43yberModulesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.apollo.dreamview.CyberModule:\x02\x38\x01\x1aH\n\x0cModulesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.apollo.dreamview.Module:\x02\x38\x01\x1a`\n\x18MonitoredComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.apollo.dreamview.MonitoredComponent:\x02\x38\x01\x1a^\n\x14OtherComponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.apollo.dreamview.ProcessMonitorConfig:\x02\x38\x01'
)




_PROCESSMONITORCONFIG = _descriptor.Descriptor(
  name='ProcessMonitorConfig',
  full_name='apollo.dreamview.ProcessMonitorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_keywords', full_name='apollo.dreamview.ProcessMonitorConfig.command_keywords', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=108,
)


_MODULEMONITORCONFIG = _descriptor.Descriptor(
  name='ModuleMonitorConfig',
  full_name='apollo.dreamview.ModuleMonitorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_name', full_name='apollo.dreamview.ModuleMonitorConfig.node_name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=150,
)


_CHANNELMONITORCONFIG = _descriptor.Descriptor(
  name='ChannelMonitorConfig',
  full_name='apollo.dreamview.ChannelMonitorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.dreamview.ChannelMonitorConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_fatal', full_name='apollo.dreamview.ChannelMonitorConfig.delay_fatal', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mandatory_fields', full_name='apollo.dreamview.ChannelMonitorConfig.mandatory_fields', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_frequency_allowed', full_name='apollo.dreamview.ChannelMonitorConfig.min_frequency_allowed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_frequency_allowed', full_name='apollo.dreamview.ChannelMonitorConfig.max_frequency_allowed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1000),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=153,
  serialized_end=310,
)


_RESOURCEMONITORCONFIG_DISKSPACE = _descriptor.Descriptor(
  name='DiskSpace',
  full_name='apollo.dreamview.ResourceMonitorConfig.DiskSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='apollo.dreamview.ResourceMonitorConfig.DiskSpace.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insufficient_space_warning', full_name='apollo.dreamview.ResourceMonitorConfig.DiskSpace.insufficient_space_warning', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insufficient_space_error', full_name='apollo.dreamview.ResourceMonitorConfig.DiskSpace.insufficient_space_error', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=632,
  serialized_end=727,
)

_RESOURCEMONITORCONFIG_CPUUSAGE = _descriptor.Descriptor(
  name='CPUUsage',
  full_name='apollo.dreamview.ResourceMonitorConfig.CPUUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='high_cpu_usage_warning', full_name='apollo.dreamview.ResourceMonitorConfig.CPUUsage.high_cpu_usage_warning', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_cpu_usage_error', full_name='apollo.dreamview.ResourceMonitorConfig.CPUUsage.high_cpu_usage_error', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_dag_path', full_name='apollo.dreamview.ResourceMonitorConfig.CPUUsage.process_dag_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=827,
)

_RESOURCEMONITORCONFIG_MEMORYUSAGE = _descriptor.Descriptor(
  name='MemoryUsage',
  full_name='apollo.dreamview.ResourceMonitorConfig.MemoryUsage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='high_memory_usage_warning', full_name='apollo.dreamview.ResourceMonitorConfig.MemoryUsage.high_memory_usage_warning', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_memory_usage_error', full_name='apollo.dreamview.ResourceMonitorConfig.MemoryUsage.high_memory_usage_error', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_dag_path', full_name='apollo.dreamview.ResourceMonitorConfig.MemoryUsage.process_dag_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=936,
)

_RESOURCEMONITORCONFIG_DISKLOAD = _descriptor.Descriptor(
  name='DiskLoad',
  full_name='apollo.dreamview.ResourceMonitorConfig.DiskLoad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='high_disk_load_warning', full_name='apollo.dreamview.ResourceMonitorConfig.DiskLoad.high_disk_load_warning', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_disk_load_error', full_name='apollo.dreamview.ResourceMonitorConfig.DiskLoad.high_disk_load_error', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='apollo.dreamview.ResourceMonitorConfig.DiskLoad.device_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=938,
  serialized_end=1031,
)

_RESOURCEMONITORCONFIG = _descriptor.Descriptor(
  name='ResourceMonitorConfig',
  full_name='apollo.dreamview.ResourceMonitorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_spaces', full_name='apollo.dreamview.ResourceMonitorConfig.disk_spaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_usages', full_name='apollo.dreamview.ResourceMonitorConfig.cpu_usages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory_usages', full_name='apollo.dreamview.ResourceMonitorConfig.memory_usages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_load_usages', full_name='apollo.dreamview.ResourceMonitorConfig.disk_load_usages', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEMONITORCONFIG_DISKSPACE, _RESOURCEMONITORCONFIG_CPUUSAGE, _RESOURCEMONITORCONFIG_MEMORYUSAGE, _RESOURCEMONITORCONFIG_DISKLOAD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=1031,
)


_MONITOREDCOMPONENT = _descriptor.Descriptor(
  name='MonitoredComponent',
  full_name='apollo.dreamview.MonitoredComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='process', full_name='apollo.dreamview.MonitoredComponent.process', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='apollo.dreamview.MonitoredComponent.channel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='apollo.dreamview.MonitoredComponent.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_for_safety', full_name='apollo.dreamview.MonitoredComponent.required_for_safety', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module', full_name='apollo.dreamview.MonitoredComponent.module', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1317,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='apollo.dreamview.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_command', full_name='apollo.dreamview.Module.start_command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_command', full_name='apollo.dreamview.Module.stop_command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_monitor_config', full_name='apollo.dreamview.Module.process_monitor_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_for_safety', full_name='apollo.dreamview.Module.required_for_safety', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1480,
)


_CYBERMODULE = _descriptor.Descriptor(
  name='CyberModule',
  full_name='apollo.dreamview.CyberModule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dag_files', full_name='apollo.dreamview.CyberModule.dag_files', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_for_safety', full_name='apollo.dreamview.CyberModule.required_for_safety', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process_group', full_name='apollo.dreamview.CyberModule.process_group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1482,
  serialized_end=1572,
)


_HMIMODE_CYBERMODULESENTRY = _descriptor.Descriptor(
  name='CyberModulesEntry',
  full_name='apollo.dreamview.HMIMode.CyberModulesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIMode.CyberModulesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIMode.CyberModulesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1867,
  serialized_end=1949,
)

_HMIMODE_MODULESENTRY = _descriptor.Descriptor(
  name='ModulesEntry',
  full_name='apollo.dreamview.HMIMode.ModulesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIMode.ModulesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIMode.ModulesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=2023,
)

_HMIMODE_MONITOREDCOMPONENTSENTRY = _descriptor.Descriptor(
  name='MonitoredComponentsEntry',
  full_name='apollo.dreamview.HMIMode.MonitoredComponentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIMode.MonitoredComponentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIMode.MonitoredComponentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2121,
)

_HMIMODE_OTHERCOMPONENTSENTRY = _descriptor.Descriptor(
  name='OtherComponentsEntry',
  full_name='apollo.dreamview.HMIMode.OtherComponentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.HMIMode.OtherComponentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.HMIMode.OtherComponentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2123,
  serialized_end=2217,
)

_HMIMODE = _descriptor.Descriptor(
  name='HMIMode',
  full_name='apollo.dreamview.HMIMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cyber_modules', full_name='apollo.dreamview.HMIMode.cyber_modules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules', full_name='apollo.dreamview.HMIMode.modules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitored_components', full_name='apollo.dreamview.HMIMode.monitored_components', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='other_components', full_name='apollo.dreamview.HMIMode.other_components', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HMIMODE_CYBERMODULESENTRY, _HMIMODE_MODULESENTRY, _HMIMODE_MONITOREDCOMPONENTSENTRY, _HMIMODE_OTHERCOMPONENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1575,
  serialized_end=2217,
)

_RESOURCEMONITORCONFIG_DISKSPACE.containing_type = _RESOURCEMONITORCONFIG
_RESOURCEMONITORCONFIG_CPUUSAGE.containing_type = _RESOURCEMONITORCONFIG
_RESOURCEMONITORCONFIG_MEMORYUSAGE.containing_type = _RESOURCEMONITORCONFIG
_RESOURCEMONITORCONFIG_DISKLOAD.containing_type = _RESOURCEMONITORCONFIG
_RESOURCEMONITORCONFIG.fields_by_name['disk_spaces'].message_type = _RESOURCEMONITORCONFIG_DISKSPACE
_RESOURCEMONITORCONFIG.fields_by_name['cpu_usages'].message_type = _RESOURCEMONITORCONFIG_CPUUSAGE
_RESOURCEMONITORCONFIG.fields_by_name['memory_usages'].message_type = _RESOURCEMONITORCONFIG_MEMORYUSAGE
_RESOURCEMONITORCONFIG.fields_by_name['disk_load_usages'].message_type = _RESOURCEMONITORCONFIG_DISKLOAD
_MONITOREDCOMPONENT.fields_by_name['process'].message_type = _PROCESSMONITORCONFIG
_MONITOREDCOMPONENT.fields_by_name['channel'].message_type = _CHANNELMONITORCONFIG
_MONITOREDCOMPONENT.fields_by_name['resource'].message_type = _RESOURCEMONITORCONFIG
_MONITOREDCOMPONENT.fields_by_name['module'].message_type = _MODULEMONITORCONFIG
_MODULE.fields_by_name['process_monitor_config'].message_type = _PROCESSMONITORCONFIG
_HMIMODE_CYBERMODULESENTRY.fields_by_name['value'].message_type = _CYBERMODULE
_HMIMODE_CYBERMODULESENTRY.containing_type = _HMIMODE
_HMIMODE_MODULESENTRY.fields_by_name['value'].message_type = _MODULE
_HMIMODE_MODULESENTRY.containing_type = _HMIMODE
_HMIMODE_MONITOREDCOMPONENTSENTRY.fields_by_name['value'].message_type = _MONITOREDCOMPONENT
_HMIMODE_MONITOREDCOMPONENTSENTRY.containing_type = _HMIMODE
_HMIMODE_OTHERCOMPONENTSENTRY.fields_by_name['value'].message_type = _PROCESSMONITORCONFIG
_HMIMODE_OTHERCOMPONENTSENTRY.containing_type = _HMIMODE
_HMIMODE.fields_by_name['cyber_modules'].message_type = _HMIMODE_CYBERMODULESENTRY
_HMIMODE.fields_by_name['modules'].message_type = _HMIMODE_MODULESENTRY
_HMIMODE.fields_by_name['monitored_components'].message_type = _HMIMODE_MONITOREDCOMPONENTSENTRY
_HMIMODE.fields_by_name['other_components'].message_type = _HMIMODE_OTHERCOMPONENTSENTRY
DESCRIPTOR.message_types_by_name['ProcessMonitorConfig'] = _PROCESSMONITORCONFIG
DESCRIPTOR.message_types_by_name['ModuleMonitorConfig'] = _MODULEMONITORCONFIG
DESCRIPTOR.message_types_by_name['ChannelMonitorConfig'] = _CHANNELMONITORCONFIG
DESCRIPTOR.message_types_by_name['ResourceMonitorConfig'] = _RESOURCEMONITORCONFIG
DESCRIPTOR.message_types_by_name['MonitoredComponent'] = _MONITOREDCOMPONENT
DESCRIPTOR.message_types_by_name['Module'] = _MODULE
DESCRIPTOR.message_types_by_name['CyberModule'] = _CYBERMODULE
DESCRIPTOR.message_types_by_name['HMIMode'] = _HMIMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProcessMonitorConfig = _reflection.GeneratedProtocolMessageType('ProcessMonitorConfig', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSMONITORCONFIG,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.ProcessMonitorConfig)
  })
_sym_db.RegisterMessage(ProcessMonitorConfig)

ModuleMonitorConfig = _reflection.GeneratedProtocolMessageType('ModuleMonitorConfig', (_message.Message,), {
  'DESCRIPTOR' : _MODULEMONITORCONFIG,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.ModuleMonitorConfig)
  })
_sym_db.RegisterMessage(ModuleMonitorConfig)

ChannelMonitorConfig = _reflection.GeneratedProtocolMessageType('ChannelMonitorConfig', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELMONITORCONFIG,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.ChannelMonitorConfig)
  })
_sym_db.RegisterMessage(ChannelMonitorConfig)

ResourceMonitorConfig = _reflection.GeneratedProtocolMessageType('ResourceMonitorConfig', (_message.Message,), {

  'DiskSpace' : _reflection.GeneratedProtocolMessageType('DiskSpace', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEMONITORCONFIG_DISKSPACE,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.ResourceMonitorConfig.DiskSpace)
    })
  ,

  'CPUUsage' : _reflection.GeneratedProtocolMessageType('CPUUsage', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEMONITORCONFIG_CPUUSAGE,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.ResourceMonitorConfig.CPUUsage)
    })
  ,

  'MemoryUsage' : _reflection.GeneratedProtocolMessageType('MemoryUsage', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEMONITORCONFIG_MEMORYUSAGE,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.ResourceMonitorConfig.MemoryUsage)
    })
  ,

  'DiskLoad' : _reflection.GeneratedProtocolMessageType('DiskLoad', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEMONITORCONFIG_DISKLOAD,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.ResourceMonitorConfig.DiskLoad)
    })
  ,
  'DESCRIPTOR' : _RESOURCEMONITORCONFIG,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.ResourceMonitorConfig)
  })
_sym_db.RegisterMessage(ResourceMonitorConfig)
_sym_db.RegisterMessage(ResourceMonitorConfig.DiskSpace)
_sym_db.RegisterMessage(ResourceMonitorConfig.CPUUsage)
_sym_db.RegisterMessage(ResourceMonitorConfig.MemoryUsage)
_sym_db.RegisterMessage(ResourceMonitorConfig.DiskLoad)

MonitoredComponent = _reflection.GeneratedProtocolMessageType('MonitoredComponent', (_message.Message,), {
  'DESCRIPTOR' : _MONITOREDCOMPONENT,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.MonitoredComponent)
  })
_sym_db.RegisterMessage(MonitoredComponent)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Module)
  })
_sym_db.RegisterMessage(Module)

CyberModule = _reflection.GeneratedProtocolMessageType('CyberModule', (_message.Message,), {
  'DESCRIPTOR' : _CYBERMODULE,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.CyberModule)
  })
_sym_db.RegisterMessage(CyberModule)

HMIMode = _reflection.GeneratedProtocolMessageType('HMIMode', (_message.Message,), {

  'CyberModulesEntry' : _reflection.GeneratedProtocolMessageType('CyberModulesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMIMODE_CYBERMODULESENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIMode.CyberModulesEntry)
    })
  ,

  'ModulesEntry' : _reflection.GeneratedProtocolMessageType('ModulesEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMIMODE_MODULESENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIMode.ModulesEntry)
    })
  ,

  'MonitoredComponentsEntry' : _reflection.GeneratedProtocolMessageType('MonitoredComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMIMODE_MONITOREDCOMPONENTSENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIMode.MonitoredComponentsEntry)
    })
  ,

  'OtherComponentsEntry' : _reflection.GeneratedProtocolMessageType('OtherComponentsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HMIMODE_OTHERCOMPONENTSENTRY,
    '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIMode.OtherComponentsEntry)
    })
  ,
  'DESCRIPTOR' : _HMIMODE,
  '__module__' : 'modules.dreamview.proto.hmi_mode_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.HMIMode)
  })
_sym_db.RegisterMessage(HMIMode)
_sym_db.RegisterMessage(HMIMode.CyberModulesEntry)
_sym_db.RegisterMessage(HMIMode.ModulesEntry)
_sym_db.RegisterMessage(HMIMode.MonitoredComponentsEntry)
_sym_db.RegisterMessage(HMIMode.OtherComponentsEntry)


_HMIMODE_CYBERMODULESENTRY._options = None
_HMIMODE_MODULESENTRY._options = None
_HMIMODE_MONITOREDCOMPONENTSENTRY._options = None
_HMIMODE_OTHERCOMPONENTSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/relative_map/proto/navigation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.localization.proto import localization_pb2 as modules_dot_localization_dot_proto_dot_localization__pb2
from modules.map.proto import map_pb2 as modules_dot_map_dot_proto_dot_map__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/relative_map/proto/navigation.proto',
  package='apollo.relative_map',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/modules/map/relative_map/proto/navigation.proto\x12\x13\x61pollo.relative_map\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/pnc_point.proto\x1a-modules/localization/proto/localization.proto\x1a\x1bmodules/map/proto/map.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\"J\n\x0eNavigationPath\x12!\n\x04path\x18\x01 \x01(\x0b\x32\x13.apollo.common.Path\x12\x15\n\rpath_priority\x18\x02 \x01(\r\"u\n\x0eNavigationInfo\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12<\n\x0fnavigation_path\x18\x02 \x03(\x0b\x32#.apollo.relative_map.NavigationPath\"\xed\x02\n\x06MapMsg\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12 \n\x05hdmap\x18\x02 \x01(\x0b\x32\x11.apollo.hdmap.Map\x12H\n\x0fnavigation_path\x18\x03 \x03(\x0b\x32/.apollo.relative_map.MapMsg.NavigationPathEntry\x12\x33\n\x0blane_marker\x18\x04 \x01(\x0b\x32\x1e.apollo.perception.LaneMarkers\x12?\n\x0clocalization\x18\x05 \x01(\x0b\x32).apollo.localization.LocalizationEstimate\x1aZ\n\x13NavigationPathEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.apollo.relative_map.NavigationPath:\x02\x38\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_localization__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,])




_NAVIGATIONPATH = _descriptor.Descriptor(
  name='NavigationPath',
  full_name='apollo.relative_map.NavigationPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='apollo.relative_map.NavigationPath.path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_priority', full_name='apollo.relative_map.NavigationPath.path_priority', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=347,
)


_NAVIGATIONINFO = _descriptor.Descriptor(
  name='NavigationInfo',
  full_name='apollo.relative_map.NavigationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.relative_map.NavigationInfo.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navigation_path', full_name='apollo.relative_map.NavigationInfo.navigation_path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=349,
  serialized_end=466,
)


_MAPMSG_NAVIGATIONPATHENTRY = _descriptor.Descriptor(
  name='NavigationPathEntry',
  full_name='apollo.relative_map.MapMsg.NavigationPathEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.relative_map.MapMsg.NavigationPathEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.relative_map.MapMsg.NavigationPathEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=834,
)

_MAPMSG = _descriptor.Descriptor(
  name='MapMsg',
  full_name='apollo.relative_map.MapMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.relative_map.MapMsg.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hdmap', full_name='apollo.relative_map.MapMsg.hdmap', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navigation_path', full_name='apollo.relative_map.MapMsg.navigation_path', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_marker', full_name='apollo.relative_map.MapMsg.lane_marker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='apollo.relative_map.MapMsg.localization', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MAPMSG_NAVIGATIONPATHENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=834,
)

_NAVIGATIONPATH.fields_by_name['path'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATH
_NAVIGATIONINFO.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_NAVIGATIONINFO.fields_by_name['navigation_path'].message_type = _NAVIGATIONPATH
_MAPMSG_NAVIGATIONPATHENTRY.fields_by_name['value'].message_type = _NAVIGATIONPATH
_MAPMSG_NAVIGATIONPATHENTRY.containing_type = _MAPMSG
_MAPMSG.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_MAPMSG.fields_by_name['hdmap'].message_type = modules_dot_map_dot_proto_dot_map__pb2._MAP
_MAPMSG.fields_by_name['navigation_path'].message_type = _MAPMSG_NAVIGATIONPATHENTRY
_MAPMSG.fields_by_name['lane_marker'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._LANEMARKERS
_MAPMSG.fields_by_name['localization'].message_type = modules_dot_localization_dot_proto_dot_localization__pb2._LOCALIZATIONESTIMATE
DESCRIPTOR.message_types_by_name['NavigationPath'] = _NAVIGATIONPATH
DESCRIPTOR.message_types_by_name['NavigationInfo'] = _NAVIGATIONINFO
DESCRIPTOR.message_types_by_name['MapMsg'] = _MAPMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

NavigationPath = _reflection.GeneratedProtocolMessageType('NavigationPath', (_message.Message,), {
  'DESCRIPTOR' : _NAVIGATIONPATH,
  '__module__' : 'modules.map.relative_map.proto.navigation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.NavigationPath)
  })
_sym_db.RegisterMessage(NavigationPath)

NavigationInfo = _reflection.GeneratedProtocolMessageType('NavigationInfo', (_message.Message,), {
  'DESCRIPTOR' : _NAVIGATIONINFO,
  '__module__' : 'modules.map.relative_map.proto.navigation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.NavigationInfo)
  })
_sym_db.RegisterMessage(NavigationInfo)

MapMsg = _reflection.GeneratedProtocolMessageType('MapMsg', (_message.Message,), {

  'NavigationPathEntry' : _reflection.GeneratedProtocolMessageType('NavigationPathEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPMSG_NAVIGATIONPATHENTRY,
    '__module__' : 'modules.map.relative_map.proto.navigation_pb2'
    # @@protoc_insertion_point(class_scope:apollo.relative_map.MapMsg.NavigationPathEntry)
    })
  ,
  'DESCRIPTOR' : _MAPMSG,
  '__module__' : 'modules.map.relative_map.proto.navigation_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.MapMsg)
  })
_sym_db.RegisterMessage(MapMsg)
_sym_db.RegisterMessage(MapMsg.NavigationPathEntry)


_MAPMSG_NAVIGATIONPATHENTRY._options = None
# @@protoc_insertion_point(module_scope)
